/**
 * @file ipsec_config.h
 * @brief CycloneIPSEC configuration file
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2022-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneIPSEC Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _IPSEC_CONFIG_H
#define _IPSEC_CONFIG_H

//Dependencies
#include "RTE_Components.h"

//*** <<< Use Configuration Wizard in Context Menu >>> ***

// <h>Trace level

// <o>IPsec Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define IPSEC_TRACE_LEVEL 0

// <o>AH Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define AH_TRACE_LEVEL 0

// <o>ESP Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define ESP_TRACE_LEVEL 0

// <o>IKEv2 Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define IKE_TRACE_LEVEL 0

// </h>
// <h>IPsec

// <q>Anti-replay mechanism
// <i>Enable support for anti-replay mechanism
// <i>Default: Enabled
#define IPSEC_ANTI_REPLAY_SUPPORT 1

// <o>Anti-replay window size
// <i>Size of the sliding window for replay protection
// <i>Default: 64
// <32-256>
#define IPSEC_ANTI_REPLAY_WINDOW_SIZE 64

// </h>
// <h>AH

// <q>ESNs support
// <i>Enable support for Extended Sequence Numbers
// <i>Default: Enabled
#define AH_ESN_SUPPORT 1

// </h>
// <h>ESP

// <q>ESNs support
// <i>Enable support for Extended Sequence Numbers
// <i>Default: Enabled
#define ESP_ESN_SUPPORT 1

// <o>Buffer size
// <i>Size of the buffer for input/output operations
// <i>Default: 2048
// <512-65536>
#define ESP_BUFFER_SIZE 2048

// </h>
// <h>IKE

// <q>Cookie support
// <i>Enable support for cookies
// <i>Default: Disabled
#define IKE_COOKIE_SUPPORT 0

// <q>INITIAL_CONTACT notification support
// <i>Enable support for INITIAL_CONTACT notifications
// <i>Default: Disabled
#define IKE_INITIAL_CONTACT_SUPPORT 1

// <q>SIGNATURE_HASH_ALGORITHMS notification support
// <i>Enable support for SIGNATURE_HASH_ALGORITHMS notifications
// <i>Default: Disabled
#define IKE_SIGN_HASH_ALGOS_SUPPORT 1

// <q>Dead peer detection support
// <i>Enable support for dead peer detection
// <i>Default: Disabled
#define IKE_DPD_SUPPORT 1

// <o>Maximum number of retransmissions of IKE requests
// <i>Maximum number of retransmissions of IKE requests
// <i>Default: 5
// <1-10>
#define IKE_MAX_RETRIES 5

// <o>Initial retransmission timeout
// <i>Initial retransmission timeout (in milliseconds)
// <i>Default: 3000
// <1000-10000>
#define IKE_INIT_TIMEOUT 3000

// <o>Maximum retransmission timeout
// <i>Maximum retransmission timeout (in milliseconds)
// <i>Default: 60000
// <1000-600000>
#define IKE_MAX_TIMEOUT 60000

// <o>Timeout for half-open IKE SAs
// <i>Timeout for half-open IKE SAs (in milliseconds)
// <i>Default: 30000
// <1000-600000>
#define IKE_HALF_OPEN_TIMEOUT 30000

// <o>Maximum size of IKE messages
// <i>Maximum size of IKE messages
// <i>Default: 1452
// <1280-16384>
#define IKE_MAX_MSG_SIZE 1452

// </h>

//IPsec support
#ifdef RTE_CYCLONE_IPSEC_IPSEC
   #define IPSEC_SUPPORT ENABLED
#else
   #define IPSEC_SUPPORT DISABLED
#endif

//AH support
#ifdef RTE_CYCLONE_IPSEC_AH
   #define AH_SUPPORT ENABLED
#else
   #define AH_SUPPORT DISABLED
#endif

//CMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_CMAC
   #define AH_CMAC_SUPPORT ENABLED
#else
   #define AH_CMAC_SUPPORT DISABLED
#endif

//HMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_HMAC
   #define AH_HMAC_SUPPORT ENABLED
#else
   #define AH_HMAC_SUPPORT DISABLED
#endif

//AES 128-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define AH_AES_128_SUPPORT ENABLED
#else
   #define AH_AES_128_SUPPORT DISABLED
#endif

//MD5 hash support (insecure)
#ifdef RTE_CYCLONE_IPSEC_MD5
   #define AH_MD5_SUPPORT ENABLED
#else
   #define AH_MD5_SUPPORT DISABLED
#endif

//SHA-1 hash support (weak)
#ifdef RTE_CYCLONE_IPSEC_SHA1
   #define AH_SHA1_SUPPORT ENABLED
#else
   #define AH_SHA1_SUPPORT DISABLED
#endif

//SHA-256 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA256
   #define AH_SHA256_SUPPORT ENABLED
#else
   #define AH_SHA256_SUPPORT DISABLED
#endif

//SHA-384 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA384
   #define AH_SHA384_SUPPORT ENABLED
#else
   #define AH_SHA384_SUPPORT DISABLED
#endif

//SHA-512 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA512
   #define AH_SHA512_SUPPORT ENABLED
#else
   #define AH_SHA512_SUPPORT DISABLED
#endif

//ESP support
#ifdef RTE_CYCLONE_IPSEC_ESP
   #define ESP_SUPPORT ENABLED
#else
   #define ESP_SUPPORT DISABLED
#endif

//CBC cipher mode support
#ifdef RTE_CYCLONE_IPSEC_CBC
   #define ESP_CBC_SUPPORT ENABLED
#else
   #define ESP_CBC_SUPPORT DISABLED
#endif

//CTR cipher mode support
#ifdef RTE_CYCLONE_IPSEC_CTR
   #define ESP_CTR_SUPPORT ENABLED
#else
   #define ESP_CTR_SUPPORT DISABLED
#endif

//CCM_8 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_8
   #define ESP_CCM_8_SUPPORT ENABLED
#else
   #define ESP_CCM_8_SUPPORT DISABLED
#endif

//CCM_12 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_12
   #define ESP_CCM_12_SUPPORT ENABLED
#else
   #define ESP_CCM_12_SUPPORT DISABLED
#endif

//CCM_16 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_16
   #define ESP_CCM_16_SUPPORT ENABLED
#else
   #define ESP_CCM_16_SUPPORT DISABLED
#endif

//GCM_8 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_8
   #define ESP_GCM_8_SUPPORT ENABLED
#else
   #define ESP_GCM_8_SUPPORT DISABLED
#endif

//GCM_12 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_12
   #define ESP_GCM_12_SUPPORT ENABLED
#else
   #define ESP_GCM_12_SUPPORT DISABLED
#endif

//GCM_16 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_16
   #define ESP_GCM_16_SUPPORT ENABLED
#else
   #define ESP_GCM_16_SUPPORT DISABLED
#endif

//ChaCha20Poly1305 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CHACHA20POLY1305
   #define ESP_CHACHA20_POLY1305_SUPPORT ENABLED
#else
   #define ESP_CHACHA20_POLY1305_SUPPORT DISABLED
#endif

//CMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_CMAC
   #define ESP_CMAC_SUPPORT ENABLED
#else
   #define ESP_CMAC_SUPPORT DISABLED
#endif

//HMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_HMAC
   #define ESP_HMAC_SUPPORT ENABLED
#else
   #define ESP_HMAC_SUPPORT DISABLED
#endif

//IDEA cipher support (insecure)
#ifdef RTE_CYCLONE_IPSEC_IDEA
   #define ESP_IDEA_SUPPORT ENABLED
#else
   #define ESP_IDEA_SUPPORT DISABLED
#endif

//DES cipher support (insecure)
#ifdef RTE_CYCLONE_IPSEC_DES
   #define ESP_DES_SUPPORT ENABLED
#else
   #define ESP_DES_SUPPORT DISABLED
#endif

//Triple DES cipher support (weak)
#ifdef RTE_CYCLONE_IPSEC_3DES
   #define ESP_3DES_SUPPORT ENABLED
#else
   #define ESP_3DES_SUPPORT DISABLED
#endif

//AES 128-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define ESP_AES_128_SUPPORT ENABLED
#else
   #define ESP_AES_128_SUPPORT DISABLED
#endif

//AES 192-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define ESP_AES_192_SUPPORT ENABLED
#else
   #define ESP_AES_192_SUPPORT DISABLED
#endif

//AES 256-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define ESP_AES_256_SUPPORT ENABLED
#else
   #define ESP_AES_256_SUPPORT DISABLED
#endif

//Camellia 128-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define ESP_CAMELLIA_128_SUPPORT ENABLED
#else
   #define ESP_CAMELLIA_128_SUPPORT DISABLED
#endif

//Camellia 192-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define ESP_CAMELLIA_192_SUPPORT ENABLED
#else
   #define ESP_CAMELLIA_192_SUPPORT DISABLED
#endif

//Camellia 256-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define ESP_CAMELLIA_256_SUPPORT ENABLED
#else
   #define ESP_CAMELLIA_256_SUPPORT DISABLED
#endif

//MD5 hash support (insecure)
#ifdef RTE_CYCLONE_IPSEC_MD5
   #define ESP_MD5_SUPPORT ENABLED
#else
   #define ESP_MD5_SUPPORT DISABLED
#endif

//SHA-1 hash support (weak)
#ifdef RTE_CYCLONE_IPSEC_SHA1
   #define ESP_SHA1_SUPPORT ENABLED
#else
   #define ESP_SHA1_SUPPORT DISABLED
#endif

//SHA-256 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA256
   #define ESP_SHA256_SUPPORT ENABLED
#else
   #define ESP_SHA256_SUPPORT DISABLED
#endif

//SHA-384 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA384
   #define ESP_SHA384_SUPPORT ENABLED
#else
   #define ESP_SHA384_SUPPORT DISABLED
#endif

//SHA-512 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA512
   #define ESP_SHA512_SUPPORT ENABLED
#else
   #define ESP_SHA512_SUPPORT DISABLED
#endif

//IKEv2 support
#ifdef RTE_CYCLONE_IPSEC_IKE
   #define IKE_SUPPORT ENABLED
#else
   #define IKE_SUPPORT DISABLED
#endif

//Certificate authentication
#ifdef RTE_CYCLONE_IPSEC_CERT_AUTH
   #define IKE_CERT_AUTH_SUPPORT ENABLED
#else
   #define IKE_CERT_AUTH_SUPPORT DISABLED
#endif

//Pre-shared key authentication
#ifdef RTE_CYCLONE_IPSEC_PSK_AUTH
   #define IKE_PSK_AUTH_SUPPORT ENABLED
#else
   #define IKE_PSK_AUTH_SUPPORT DISABLED
#endif

//CBC cipher mode support
#ifdef RTE_CYCLONE_IPSEC_CBC
   #define IKE_CBC_SUPPORT ENABLED
#else
   #define IKE_CBC_SUPPORT DISABLED
#endif

//CTR cipher mode support
#ifdef RTE_CYCLONE_IPSEC_CTR
   #define IKE_CTR_SUPPORT ENABLED
#else
   #define IKE_CTR_SUPPORT DISABLED
#endif

//CCM_8 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_8
   #define IKE_CCM_8_SUPPORT ENABLED
#else
   #define IKE_CCM_8_SUPPORT DISABLED
#endif

//CCM_12 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_12
   #define IKE_CCM_12_SUPPORT ENABLED
#else
   #define IKE_CCM_12_SUPPORT DISABLED
#endif

//CCM_16 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CCM_16
   #define IKE_CCM_16_SUPPORT ENABLED
#else
   #define IKE_CCM_16_SUPPORT DISABLED
#endif

//GCM_8 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_8
   #define IKE_GCM_8_SUPPORT ENABLED
#else
   #define IKE_GCM_8_SUPPORT DISABLED
#endif

//GCM_12 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_12
   #define IKE_GCM_12_SUPPORT ENABLED
#else
   #define IKE_GCM_12_SUPPORT DISABLED
#endif

//GCM_16 AEAD support
#ifdef RTE_CYCLONE_IPSEC_GCM_16
   #define IKE_GCM_16_SUPPORT ENABLED
#else
   #define IKE_GCM_16_SUPPORT DISABLED
#endif

//ChaCha20Poly1305 AEAD support
#ifdef RTE_CYCLONE_IPSEC_CHACHA20POLY1305
   #define IKE_CHACHA20_POLY1305_SUPPORT ENABLED
#else
   #define IKE_CHACHA20_POLY1305_SUPPORT DISABLED
#endif

//CMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_CMAC
   #define IKE_CMAC_AUTH_SUPPORT ENABLED
#else
   #define IKE_CMAC_AUTH_SUPPORT DISABLED
#endif

//HMAC integrity support
#ifdef RTE_CYCLONE_IPSEC_HMAC
   #define IKE_HMAC_AUTH_SUPPORT ENABLED
#else
   #define IKE_HMAC_AUTH_SUPPORT DISABLED
#endif

//XCBC-MAC integrity support
#ifdef RTE_CYCLONE_IPSEC_XCBC_MAC
   #define IKE_XCBC_MAC_AUTH_SUPPORT ENABLED
#else
   #define IKE_XCBC_MAC_AUTH_SUPPORT DISABLED
#endif

//CMAC PRF support
#ifdef RTE_CYCLONE_IPSEC_CMAC
   #define IKE_CMAC_PRF_SUPPORT ENABLED
#else
   #define IKE_CMAC_PRF_SUPPORT DISABLED
#endif

//HMAC PRF support
#ifdef RTE_CYCLONE_IPSEC_HMAC
   #define IKE_HMAC_PRF_SUPPORT ENABLED
#else
   #define IKE_HMAC_PRF_SUPPORT DISABLED
#endif

//XCBC-MAC PRF support
#ifdef RTE_CYCLONE_IPSEC_XCBC_MAC
   #define IKE_XCBC_MAC_PRF_SUPPORT ENABLED
#else
   #define IKE_XCBC_MAC_PRF_SUPPORT DISABLED
#endif

//IDEA cipher support (insecure)
#ifdef RTE_CYCLONE_IPSEC_IDEA
   #define IKE_IDEA_SUPPORT ENABLED
#else
   #define IKE_IDEA_SUPPORT DISABLED
#endif

//DES cipher support (insecure)
#ifdef RTE_CYCLONE_IPSEC_DES
   #define IKE_DES_SUPPORT ENABLED
#else
   #define IKE_DES_SUPPORT DISABLED
#endif

//Triple DES cipher support (weak)
#ifdef RTE_CYCLONE_IPSEC_3DES
   #define IKE_3DES_SUPPORT ENABLED
#else
   #define IKE_3DES_SUPPORT DISABLED
#endif

//AES 128-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define IKE_AES_128_SUPPORT ENABLED
#else
   #define IKE_AES_128_SUPPORT DISABLED
#endif

//AES 192-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define IKE_AES_192_SUPPORT ENABLED
#else
   #define IKE_AES_192_SUPPORT DISABLED
#endif

//AES 256-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_AES
   #define IKE_AES_256_SUPPORT ENABLED
#else
   #define IKE_AES_256_SUPPORT DISABLED
#endif

//Camellia 128-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define IKE_CAMELLIA_128_SUPPORT ENABLED
#else
   #define IKE_CAMELLIA_128_SUPPORT DISABLED
#endif

//Camellia 192-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define IKE_CAMELLIA_192_SUPPORT ENABLED
#else
   #define IKE_CAMELLIA_192_SUPPORT DISABLED
#endif

//Camellia 256-bit cipher support
#ifdef RTE_CYCLONE_IPSEC_CAMELLIA
   #define IKE_CAMELLIA_256_SUPPORT ENABLED
#else
   #define IKE_CAMELLIA_256_SUPPORT DISABLED
#endif

//MD5 hash support (insecure)
#ifdef RTE_CYCLONE_IPSEC_MD5
   #define IKE_MD5_SUPPORT ENABLED
#else
   #define IKE_MD5_SUPPORT DISABLED
#endif

//SHA-1 hash support (weak)
#ifdef RTE_CYCLONE_IPSEC_SHA1
   #define IKE_SHA1_SUPPORT ENABLED
#else
   #define IKE_SHA1_SUPPORT DISABLED
#endif

//SHA-256 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA256
   #define IKE_SHA256_SUPPORT ENABLED
#else
   #define IKE_SHA256_SUPPORT DISABLED
#endif

//SHA-384 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA384
   #define IKE_SHA384_SUPPORT ENABLED
#else
   #define IKE_SHA384_SUPPORT DISABLED
#endif

//SHA-512 hash support
#ifdef RTE_CYCLONE_IPSEC_SHA512
   #define IKE_SHA512_SUPPORT ENABLED
#else
   #define IKE_SHA512_SUPPORT DISABLED
#endif

//Tiger hash support
#ifdef RTE_CYCLONE_IPSEC_TIGER
   #define IKE_TIGER_SUPPORT ENABLED
#else
   #define IKE_TIGER_SUPPORT DISABLED
#endif

//Diffie-Hellman key exchange support
#ifdef RTE_CYCLONE_IPSEC_DH_KE
   #define IKE_DH_KE_SUPPORT ENABLED
#else
   #define IKE_DH_KE_SUPPORT DISABLED
#endif

//ECDH key exchange support
#ifdef RTE_CYCLONE_IPSEC_ECDH_KE
   #define IKE_ECDH_KE_SUPPORT ENABLED
#else
   #define IKE_ECDH_KE_SUPPORT DISABLED
#endif

//RSA signature support
#ifdef RTE_CYCLONE_IPSEC_RSA_SIGN
   #define IKE_RSA_SIGN_SUPPORT ENABLED
#else
   #define IKE_RSA_SIGN_SUPPORT DISABLED
#endif

//RSA-PSS signature support
#ifdef RTE_CYCLONE_IPSEC_RSA_PSS_SIGN
   #define IKE_RSA_PSS_SIGN_SUPPORT ENABLED
#else
   #define IKE_RSA_PSS_SIGN_SUPPORT DISABLED
#endif

//DSA signature support
#ifdef RTE_CYCLONE_IPSEC_DSA_SIGN
   #define IKE_DSA_SIGN_SUPPORT ENABLED
#else
   #define IKE_DSA_SIGN_SUPPORT DISABLED
#endif

//ECDSA signature support
#ifdef RTE_CYCLONE_IPSEC_ECDSA_SIGN
   #define IKE_ECDSA_SIGN_SUPPORT ENABLED
#else
   #define IKE_ECDSA_SIGN_SUPPORT DISABLED
#endif

//Ed25519 signature support
#ifdef RTE_CYCLONE_IPSEC_ED25519_SIGN
   #define IKE_ED25519_SIGN_SUPPORT ENABLED
#else
   #define IKE_ED25519_SIGN_SUPPORT DISABLED
#endif

//Ed448 signature support
#ifdef RTE_CYCLONE_IPSEC_ED448_SIGN
   #define IKE_ED448_SIGN_SUPPORT ENABLED
#else
   #define IKE_ED448_SIGN_SUPPORT DISABLED
#endif

//NIST P-192 elliptic curve support (weak)
#ifdef RTE_CYCLONE_IPSEC_ECP_192
   #define IKE_ECP_192_SUPPORT ENABLED
#else
   #define IKE_ECP_192_SUPPORT DISABLED
#endif

//NIST P-224 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_ECP_224
   #define IKE_ECP_224_SUPPORT ENABLED
#else
   #define IKE_ECP_224_SUPPORT DISABLED
#endif

//NIST P-256 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_ECP_256
   #define IKE_ECP_256_SUPPORT ENABLED
#else
   #define IKE_ECP_256_SUPPORT DISABLED
#endif

//NIST P-384 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_ECP_384
   #define IKE_ECP_384_SUPPORT ENABLED
#else
   #define IKE_ECP_384_SUPPORT DISABLED
#endif

//NIST P-521 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_ECP_521
   #define IKE_ECP_521_SUPPORT ENABLED
#else
   #define IKE_ECP_521_SUPPORT DISABLED
#endif

//brainpoolP224r1 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_BRAINPOOLP224R1
   #define IKE_BRAINPOOLP224R1_SUPPORT ENABLED
#else
   #define IKE_BRAINPOOLP224R1_SUPPORT DISABLED
#endif

//brainpoolP256r1 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_BRAINPOOLP256R1
   #define IKE_BRAINPOOLP256R1_SUPPORT ENABLED
#else
   #define IKE_BRAINPOOLP256R1_SUPPORT DISABLED
#endif

//brainpoolP384r1 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_BRAINPOOLP384R1
   #define IKE_BRAINPOOLP384R1_SUPPORT ENABLED
#else
   #define IKE_BRAINPOOLP384R1_SUPPORT DISABLED
#endif

//brainpoolP512r1 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_BRAINPOOLP512R1
   #define IKE_BRAINPOOLP512R1_SUPPORT ENABLED
#else
   #define IKE_BRAINPOOLP512R1_SUPPORT DISABLED
#endif

//Curve25519 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_CURVE25519
   #define IKE_CURVE25519_SUPPORT ENABLED
#else
   #define IKE_CURVE25519_SUPPORT DISABLED
#endif

//Curve448 elliptic curve support
#ifdef RTE_CYCLONE_IPSEC_CURVE448
   #define IKE_CURVE448_SUPPORT ENABLED
#else
   #define IKE_CURVE448_SUPPORT DISABLED
#endif

#endif
