/**
 * @file stp_common.h
 * @brief STP common definitions
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2019-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneSTP Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _STP_COMMON_H
#define _STP_COMMON_H

//Dependencies
#include "stp_config.h"
#include "core/net.h"

//Version string
#define CYCLONE_STP_VERSION_STRING "2.4.4"
//Major version
#define CYCLONE_STP_MAJOR_VERSION 2
//Minor version
#define CYCLONE_STP_MINOR_VERSION 4
//Revision number
#define CYCLONE_STP_REV_NUMBER 4

//C++ guard
#ifdef __cplusplus
extern "C" {
#endif

//Protocol identifier
#define STP_PROTOCOL_ID 0

//LLC header fields
#define STP_LLC_DSAP 0x42
#define STP_LLC_SSAP 0x42
#define STP_LLC_CTRL 0x03

//Minimum size of BPDUs
#define STP_MIN_BPDU_SIZE 4


/**
 * @brief Protocol versions
 **/

typedef enum
{
   STP_PROTOCOL_VERSION  = 0, ///<STP version
   RSTP_PROTOCOL_VERSION = 2, ///<RSTP version
   MSTP_PROTOCOL_VERSION = 3  ///<MSTP version
} StpProtocolVersion;


/**
 * @brief Port states
 **/

typedef enum
{
   STP_PORT_STATE_DISABLED   = 0,
   STP_PORT_STATE_BROKEN     = 1,
   STP_PORT_STATE_BLOCKING   = 2,
   STP_PORT_STATE_LISTENING  = 3,
   STP_PORT_STATE_LEARNING   = 4,
   STP_PORT_STATE_FORWARDING = 5
} StpPortState;


/**
 * @brief Port role values
 **/

typedef enum
{
   STP_PORT_ROLE_DISABLED   = 0,
   STP_PORT_ROLE_ROOT       = 1,
   STP_PORT_ROLE_DESIGNATED = 2,
   STP_PORT_ROLE_ALTERNATE  = 3,
   STP_PORT_ROLE_BACKUP     = 4
} StpPortRole;


//CC-RX, CodeWarrior or Win32 compiler?
#if defined(__CCRX__)
   #pragma pack
#elif defined(__CWCC__) || defined(_WIN32)
   #pragma pack(push, 1)
#endif


/**
 * @brief Bridge identifier
 **/

typedef __packed_struct
{
   uint16_t priority; //0-1
   MacAddr addr;      //2-7
} StpBridgeId;


//CC-RX, CodeWarrior or Win32 compiler?
#if defined(__CCRX__)
   #pragma unpack
#elif defined(__CWCC__) || defined(_WIN32)
   #pragma pack(pop)
#endif

//C++ guard
#ifdef __cplusplus
}
#endif

#endif
