/**
 * @file os_port_config.h
 * @brief RTOS port configuration file
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2010-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _OS_PORT_CONFIG_H
#define _OS_PORT_CONFIG_H

//Dependencies
#include "RTE_Components.h"

//Select underlying RTOS
#if defined(RTE_CMSIS_RTOS)
   #define USE_CMSIS_RTOS
#elif defined(RTE_CMSIS_RTOS2)
   #define USE_CMSIS_RTOS2
#elif defined(RTE_RTOS_FreeRTOS_CORE)
   #define USE_FREERTOS
#else
   #define USE_NO_RTOS
#endif

//Trace output redirection
int fprintf_custom(void *stream, const char *format, ...);
#define TRACE_PRINTF(...) osSuspendAllTasks(), fprintf_custom(stderr, __VA_ARGS__), osResumeAllTasks()

#endif
