/**
 * @file ssh_config.h
 * @brief CycloneSSH configuration file
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2010-2019 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneSSH Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _SSH_CONFIG_H
#define _SSH_CONFIG_H

//Dependencies
#include "RTE_Components.h"

//*** <<< Use Configuration Wizard in Context Menu >>> ***

// <h>Trace level

// <o>SSH Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define SSH_TRACE_LEVEL 4

// <o>SCP Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define SCP_TRACE_LEVEL 4

// <o>SFTP Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define SFTP_TRACE_LEVEL 4

// <o>Shell Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define SHELL_TRACE_LEVEL 4

// </h>

//SSH support
#ifdef RTE_CYCLONE_SSH
   #define SSH_SUPPORT ENABLED
#else
   #define SSH_SUPPORT DISABLED
#endif

//SSH client support
#ifdef RTE_CYCLONE_SSH_CLIENT
   #define SSH_CLIENT_SUPPORT ENABLED
#else
   #define SSH_CLIENT_SUPPORT DISABLED
#endif

//SSH server support
#ifdef RTE_CYCLONE_SSH_SERVER
   #define SSH_SERVER_SUPPORT ENABLED
#else
   #define SSH_SERVER_SUPPORT DISABLED
#endif

//Password authentication support
#ifdef RTE_CYCLONE_SSH_PASSWORD_AUTH
   #define SSH_PASSWORD_AUTH_SUPPORT ENABLED
#else
   #define SSH_PASSWORD_AUTH_SUPPORT DISABLED
#endif

//Public key authentication support
#ifdef RTE_CYCLONE_SSH_PUBLIC_KEY_AUTH
   #define SSH_PUBLIC_KEY_AUTH_SUPPORT ENABLED
#else
   #define SSH_PUBLIC_KEY_AUTH_SUPPORT DISABLED
#endif

//Stream cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_STREAM
   #define SSH_STREAM_CIPHER_SUPPORT ENABLED
#else
   #define SSH_STREAM_CIPHER_SUPPORT DISABLED
#endif

//CBC cipher mode support (weak)
#ifdef RTE_CYCLONE_SSH_CBC
   #define SSH_CBC_CIPHER_SUPPORT ENABLED
#else
   #define SSH_CBC_CIPHER_SUPPORT DISABLED
#endif

//CTR cipher mode support
#ifdef RTE_CYCLONE_SSH_CTR
   #define SSH_CTR_CIPHER_SUPPORT ENABLED
#else
   #define SSH_CTR_CIPHER_SUPPORT DISABLED
#endif

//GCM AEAD support
#ifdef RTE_CYCLONE_SSH_GCM
   #define SSH_GCM_CIPHER_SUPPORT ENABLED
#else
   #define SSH_GCM_CIPHER_SUPPORT DISABLED
#endif

//ChaCha20Poly1305 AEAD support
#ifdef RTE_CYCLONE_SSH_CHACHA20POLY1305
   #define SSH_CHACHA20_POLY1305_SUPPORT ENABLED
#else
   #define SSH_CHACHA20_POLY1305_SUPPORT DISABLED
#endif

//RC4 128-bit cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_RC4
   #define SSH_RC4_128_SUPPORT ENABLED
#else
   #define SSH_RC4_128_SUPPORT DISABLED
#endif

//RC4 256-bit cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_RC4
   #define SSH_RC4_256_SUPPORT ENABLED
#else
   #define SSH_RC4_256_SUPPORT DISABLED
#endif

//CAST-128 cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_CAST128
   #define SSH_CAST128_SUPPORT ENABLED
#else
   #define SSH_CAST128_SUPPORT DISABLED
#endif

//IDEA cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_IDEA
   #define SSH_IDEA_SUPPORT ENABLED
#else
   #define SSH_IDEA_SUPPORT DISABLED
#endif

//Blowfish cipher support (insecure)
#ifdef RTE_CYCLONE_SSH_BLOWFISH
   #define SSH_BLOWFISH_SUPPORT ENABLED
#else
   #define SSH_BLOWFISH_SUPPORT DISABLED
#endif

//Triple DES cipher support (weak)
#ifdef RTE_CYCLONE_SSH_3DES
   #define SSH_3DES_SUPPORT ENABLED
#else
   #define SSH_3DES_SUPPORT DISABLED
#endif

//AES 128-bit cipher support
#ifdef RTE_CYCLONE_SSH_AES
   #define SSH_AES_128_SUPPORT ENABLED
#else
   #define SSH_AES_128_SUPPORT DISABLED
#endif

//AES 192-bit cipher support
#ifdef RTE_CYCLONE_SSH_AES
   #define SSH_AES_192_SUPPORT ENABLED
#else
   #define SSH_AES_192_SUPPORT DISABLED
#endif

//AES 256-bit cipher support
#ifdef RTE_CYCLONE_SSH_AES
   #define SSH_AES_256_SUPPORT ENABLED
#else
   #define SSH_AES_256_SUPPORT DISABLED
#endif

//Twofish 128-bit cipher support
#ifdef RTE_CYCLONE_SSH_TWOFISH
   #define SSH_TWOFISH_128_SUPPORT ENABLED
#else
   #define SSH_TWOFISH_128_SUPPORT DISABLED
#endif

//Twofish 192-bit cipher support
#ifdef RTE_CYCLONE_SSH_TWOFISH
   #define SSH_TWOFISH_192_SUPPORT ENABLED
#else
   #define SSH_TWOFISH_192_SUPPORT DISABLED
#endif

//Twofish 256-bit cipher support
#ifdef RTE_CYCLONE_SSH_TWOFISH
   #define SSH_TWOFISH_256_SUPPORT ENABLED
#else
   #define SSH_TWOFISH_256_SUPPORT DISABLED
#endif

//Serpent 128-bit cipher support
#ifdef RTE_CYCLONE_SSH_SERPENT
   #define SSH_SERPENT_128_SUPPORT ENABLED
#else
   #define SSH_SERPENT_128_SUPPORT DISABLED
#endif

//Serpent 192-bit cipher support
#ifdef RTE_CYCLONE_SSH_SERPENT
   #define SSH_SERPENT_192_SUPPORT ENABLED
#else
   #define SSH_SERPENT_192_SUPPORT DISABLED
#endif

//Serpent 256-bit cipher support
#ifdef RTE_CYCLONE_SSH_SERPENT
   #define SSH_SERPENT_256_SUPPORT ENABLED
#else
   #define SSH_SERPENT_256_SUPPORT DISABLED
#endif

//Camellia 128-bit cipher support
#ifdef RTE_CYCLONE_SSH_CAMELLIA
   #define SSH_CAMELLIA_128_SUPPORT ENABLED
#else
   #define SSH_CAMELLIA_128_SUPPORT DISABLED
#endif

//Camellia 192-bit cipher support
#ifdef RTE_CYCLONE_SSH_CAMELLIA
   #define SSH_CAMELLIA_192_SUPPORT ENABLED
#else
   #define SSH_CAMELLIA_192_SUPPORT DISABLED
#endif

//Camellia 256-bit cipher support
#ifdef RTE_CYCLONE_SSH_CAMELLIA
   #define SSH_CAMELLIA_256_SUPPORT ENABLED
#else
   #define SSH_CAMELLIA_256_SUPPORT DISABLED
#endif

//SEED cipher support
#ifdef RTE_CYCLONE_SSH_SEED
   #define SSH_SEED_SUPPORT ENABLED
#else
   #define SSH_SEED_SUPPORT DISABLED
#endif

//MD5 hash support (insecure)
#ifdef RTE_CYCLONE_SSH_MD5
   #define SSH_MD5_SUPPORT ENABLED
#else
   #define SSH_MD5_SUPPORT DISABLED
#endif

//MD5/96 hash support (insecure)
#ifdef RTE_CYCLONE_SSH_MD5_96
   #define SSH_MD5_96_SUPPORT ENABLED
#else
   #define SSH_MD5_96_SUPPORT DISABLED
#endif

//RIPEMD-160 hash support (weak)
#ifdef RTE_CYCLONE_SSH_RIPEMD160
   #define SSH_RIPEMD160_SUPPORT ENABLED
#else
   #define SSH_RIPEMD160_SUPPORT DISABLED
#endif

//SHA-1 hash support (weak)
#ifdef RTE_CYCLONE_SSH_SHA1
   #define SSH_SHA1_SUPPORT ENABLED
#else
   #define SSH_SHA1_SUPPORT DISABLED
#endif

//SHA-1/96 hash support (insecure)
#ifdef RTE_CYCLONE_SSH_SHA1_96
   #define SSH_SHA1_96_SUPPORT ENABLED
#else
   #define SSH_SHA1_96_SUPPORT DISABLED
#endif

//SHA-256 hash support
#ifdef RTE_CYCLONE_SSH_SHA256
   #define SSH_SHA256_SUPPORT ENABLED
#else
   #define SSH_SHA256_SUPPORT DISABLED
#endif

//SHA-384 hash support
#ifdef RTE_CYCLONE_SSH_SHA384
   #define SSH_SHA384_SUPPORT ENABLED
#else
   #define SSH_SHA384_SUPPORT DISABLED
#endif

//SHA-512 hash support
#ifdef RTE_CYCLONE_SSH_SHA512
   #define SSH_SHA512_SUPPORT ENABLED
#else
   #define SSH_SHA512_SUPPORT DISABLED
#endif

//RSA key exchange support
#ifdef RTE_CYCLONE_SSH_RSA_KEX
   #define SSH_RSA_KEX_SUPPORT ENABLED
#else
   #define SSH_RSA_KEX_SUPPORT DISABLED
#endif

//Diffie-Hellman key exchange support
#ifdef RTE_CYCLONE_SSH_DH_KEX
   #define SSH_DH_KEX_SUPPORT ENABLED
#else
   #define SSH_DH_KEX_SUPPORT DISABLED
#endif

//DH GEX key exchange support
#ifdef RTE_CYCLONE_SSH_DH_GEX_KEX
   #define SSH_DH_GEX_KEX_SUPPORT ENABLED
#else
   #define SSH_DH_GEX_KEX_SUPPORT DISABLED
#endif

//ECDH key exchange support
#ifdef RTE_CYCLONE_SSH_ECDH_KEX
   #define SSH_ECDH_KEX_SUPPORT ENABLED
#else
   #define SSH_ECDH_KEX_SUPPORT DISABLED
#endif

//RSA signature support
#ifdef RTE_CYCLONE_SSH_RSA_SIGN
   #define SSH_RSA_SIGN_SUPPORT ENABLED
#else
   #define SSH_RSA_SIGN_SUPPORT DISABLED
#endif

//DSA signature support
#ifdef RTE_CYCLONE_SSH_DSA_SIGN
   #define SSH_DSA_SIGN_SUPPORT ENABLED
#else
   #define SSH_DSA_SIGN_SUPPORT DISABLED
#endif

//ECDSA signature support
#ifdef RTE_CYCLONE_SSH_ECDSA_SIGN
   #define SSH_ECDSA_SIGN_SUPPORT ENABLED
#else
   #define SSH_ECDSA_SIGN_SUPPORT DISABLED
#endif

//Ed25519 signature support
#ifdef RTE_CYCLONE_SSH_ED25519_SIGN
   #define SSH_ED25519_SIGN_SUPPORT ENABLED
#else
   #define SSH_ED25519_SIGN_SUPPORT DISABLED
#endif

//Ed448 signature support
#ifdef RTE_CYCLONE_SSH_ED448_SIGN
   #define SSH_ED448_SIGN_SUPPORT ENABLED
#else
   #define SSH_ED448_SIGN_SUPPORT DISABLED
#endif

//NIST P-256 elliptic curve support
#ifdef RTE_CYCLONE_SSH_NISTP256
   #define SSH_NISTP256_SUPPORT ENABLED
#else
   #define SSH_NISTP256_SUPPORT DISABLED
#endif

//NIST P-384 elliptic curve support
#ifdef RTE_CYCLONE_SSH_NISTP384
   #define SSH_NISTP384_SUPPORT ENABLED
#else
   #define SSH_NISTP384_SUPPORT DISABLED
#endif

//NIST P-521 elliptic curve support
#ifdef RTE_CYCLONE_SSH_NISTP521
   #define SSH_NISTP521_SUPPORT ENABLED
#else
   #define SSH_NISTP521_SUPPORT DISABLED
#endif

//Curve25519 elliptic curve support
#ifdef RTE_CYCLONE_SSH_CURVE25519
   #define SSH_CURVE25519_SUPPORT ENABLED
#else
   #define SSH_CURVE25519_SUPPORT DISABLED
#endif

//Curve448 elliptic curve support
#ifdef RTE_CYCLONE_SSH_CURVE448
   #define SSH_CURVE448_SUPPORT ENABLED
#else
   #define SSH_CURVE448_SUPPORT DISABLED
#endif

//SCP client support
#ifdef RTE_CYCLONE_SSH_SCP_CLIENT
   #define SCP_CLIENT_SUPPORT ENABLED
#else
   #define SCP_CLIENT_SUPPORT DISABLED
#endif

//SCP server support
#ifdef RTE_CYCLONE_SSH_SCP_SERVER
   #define SCP_SERVER_SUPPORT ENABLED
#else
   #define SCP_SERVER_SUPPORT DISABLED
#endif

//SFTP client support
#ifdef RTE_CYCLONE_SSH_SFTP_CLIENT
   #define SFTP_CLIENT_SUPPORT ENABLED
#else
   #define SFTP_CLIENT_SUPPORT DISABLED
#endif

//SFTP server support
#ifdef RTE_CYCLONE_SSH_SFTP_SERVER
   #define SFTP_SERVER_SUPPORT ENABLED
#else
   #define SFTP_SERVER_SUPPORT DISABLED
#endif

//Shell client support
#ifdef RTE_CYCLONE_SSH_SHELL_CLIENT
   #define SHELL_CLIENT_SUPPORT ENABLED
#else
   #define SHELL_CLIENT_SUPPORT DISABLED
#endif

//Shell server support
#ifdef RTE_CYCLONE_SSH_SHELL_SERVER
   #define SHELL_SERVER_SUPPORT ENABLED
#else
   #define SHELL_SERVER_SUPPORT DISABLED
#endif

#endif
