/**
 * @file eap_config.h
 * @brief CycloneEAP configuration file
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2022-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneTCP Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _EAP_CONFIG_H
#define _EAP_CONFIG_H

//Dependencies
#include "RTE_Components.h"

//*** <<< Use Configuration Wizard in Context Menu >>> ***

// <h>Trace level

// <o>EAP Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define EAP_TRACE_LEVEL 4

// <o>RADIUS Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define RADIUS_TRACE_LEVEL 0

// <o>802.1X Supplicant Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define SUPPLICANT_TRACE_LEVEL 4

// <o>802.1X Authenticator Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define AUTHENTICATOR_TRACE_LEVEL 0

// </h>
// <h>IEEE8021-PAE-MIB

// <q>SET operation support
// <i>Enable support for SET operations
// <i>Default: Disable
#define IEEE8021_PAE_MIB_SET_SUPPORT 0

// </h>

//802.1X supplicant support
#ifdef RTE_CYCLONE_EAP_SUPPLICANT
   #define SUPPLICANT_SUPPORT ENABLED
#else
   #define SUPPLICANT_SUPPORT DISABLED
#endif

//802.1X authenticator support
#ifdef RTE_CYCLONE_EAP_AUTHENTICATOR
   #define AUTHENTICATOR_SUPPORT ENABLED
#else
   #define AUTHENTICATOR_SUPPORT DISABLED
#endif

//MD5-Challenge authentication method support
#ifdef RTE_CYCLONE_EAP_MD5
   #define EAP_MD5_SUPPORT ENABLED
#else
   #define EAP_MD5_SUPPORT DISABLED
#endif

//EAP-TLS authentication method support
#ifdef RTE_CYCLONE_EAP_TLS
   #define EAP_TLS_SUPPORT ENABLED
#else
   #define EAP_TLS_SUPPORT DISABLED
#endif

//Port Access Control MIB module support
#ifdef RTE_CYCLONE_EAP_IEEE8021_PAE_MIB
   #define IEEE8021_PAE_MIB_SUPPORT ENABLED
#else
   #define IEEE8021_PAE_MIB_SUPPORT DISABLED
#endif

#endif
