/**
 * @file acme_config.h
 * @brief CycloneACME configuration file
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2019-2024 Oryx Embedded SARL. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.4.4
 **/

#ifndef _ACME_CONFIG_H
#define _ACME_CONFIG_H

//Dependencies
#include "RTE_Components.h"

//*** <<< Use Configuration Wizard in Context Menu >>> ***

// <h>Trace level

// <o>ACME Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define ACME_TRACE_LEVEL 5

// <o>ACME-DNS Trace level
// <i>Set the desired debugging level
// <i>Default: Info
// <0=>Off
// <1=>Fatal
// <2=>Error
// <3=>Warning
// <4=>Info
// <5=>Debug
// <6=>Verbose
#define ACME_DNS_TRACE_LEVEL 0

// </h>
// <h>ACME Client

// <q>HTTP challenge support
// <i>Enable support for HTTP challenge
// <i>Default: Enable
#define ACME_CLIENT_HTTP_CHALLENGE_SUPPORT 1

// <q>DNS challenge support
// <i>Enable support for DNS challenge
// <i>Default: Disable
#define ACME_CLIENT_DNS_CHALLENGE_SUPPORT 0

// <q>TLS-ALPN challenge support
// <i>Enable support for TLS-ALPN challenge
// <i>Default: Enable
#define ACME_CLIENT_TLS_ALPN_CHALLENGE_SUPPORT 1

// <o>Maximum number of domains per certificate order
// <i>Set the maximum number of domains per certificate order
// <i>Default: 2
// <1-10>
#define ACME_CLIENT_MAX_DOMAINS 2

// </h>

//ACME client support
#ifdef RTE_CYCLONE_ACME_ACME_CLIENT
   #define ACME_CLIENT_SUPPORT ENABLED
#else
   #define ACME_CLIENT_SUPPORT DISABLED
#endif

//ACME-DNS client support
#ifdef RTE_CYCLONE_ACME_ACME_DNS_CLIENT
   #define ACME_DNS_CLIENT_SUPPORT ENABLED
#else
   #define ACME_DNS_CLIENT_SUPPORT DISABLED
#endif

//ACME-DNS over TLS
#ifdef RTE_CYCLONE_ACME_ACME_DNS_CLIENT_TLS
   #define ACME_DNS_CLIENT_TLS_SUPPORT ENABLED
#else
   #define ACME_DNS_CLIENT_TLS_SUPPORT DISABLED
#endif

#endif
